Financial Data
====================

This example retrieves financial data from the Federal Reserve Bank of St. Louis and builds models in DataRobot to predict recession.


.. toctree::
   :maxdepth: 1

   generating_data.ipynb
   predict_your_fortunes.ipynb
